==> digikam-4.12.0.tar.bz2: digikam-4.12.0/extra/kipi-plugins/kmlexport/kipiplugin_kmlexport.desktop.cmake <==
[Desktop Entry]
Comment=A tool to create KML files with geolocated images
Comment[bs]=Alat za kreiranje KML datoteka s geolociranim slikama
Comment[ca]=Una eina per crear fitxers KML per presentar imatges amb coordenades
Comment[cs]=Modul pro vytváření souborů KML s obrázky se souřadnicemi.
Comment[da]=Et værktøj til at oprette KML-filer med geolokaliserede billeder
Comment[de]=Ein Werkzeug zum Erstellen von KML-Dateien mit Bilder, die geografische Informationen enthalten.
Comment[el]=Ένα πρόσθετο δημιουργίας αρχείων KML με γεωχωρικές εικόνες
Comment[en_GB]=A tool to create KML files with geolocated images
Comment[es]=Una herramienta para crear archivos KML con imágenes geolocalizadas
Comment[gl]=Unha ferramenta para crear ficheiros KML con imaxes que inclúen coordenadas.
Comment[is]=Verkfæri til að búa til KML-skrár fyrir hnattstaðsetningu mynda.
Comment[it]=Uno strumento per creare file KML con immagini geolocalizzate.
Comment[nl]=Een hulpmiddel om KML-bestanden aan te maken met afbeeldingen met geo-locaties.
Comment[pl]=Narzędzie do tworzenia plików KML z obrazów o ustalonym położeniu geograficznym
Comment[pt]=Um 'plugin' para criar ficheiros KML com imagens geo-localizadas.
Comment[pt_BR]=Ferramenta para criar arquivos KML com imagens geolocalizadas.
Comment[ru]=Инструмент для создания файлов KML из изображений с географическими координатами
Comment[sk]=Nástroj na tvorbu KML súborov s geolokalizovanými obrázkami
Comment[sl]=Orodje za ustvarjanje datotek KML, ki predstavijo sliko s koordinatami
Comment[sv]=Ett verktyg för att skapa KML-filer med geografiskt lokaliserade bilder
Comment[tr]=Konum içeren resimlerden KML dosyaları oluşturmak için bir araç
Comment[uk]=Інструмент для створення файлів KML для показу зображення з координатами
Comment[x-test]=xxA tool to create KML files with geolocated imagesxx
Icon=applications-development-web
UntranslatedGenericName=KMLExport
Name=KMLExport
Name[bg]=Изнасяне в KML
Name[bs]=KMLExport
Name[ca]=Exportador a KML
Name[ca@valencia]=Exportador a KML
Name[cs]=KMLExport
Name[da]=KMLExport
Name[de]=KMLExport
Name[el]=KMLExport
Name[en_GB]=KMLExport
Name[es]=KMLExport
Name[et]=KML-i eksport
Name[fi]=KML-vienti
Name[fr]=Exportation « KML »
Name[ga]=KMLExport
Name[gl]=KMLExport
Name[hu]=KML exportálás
Name[is]=KMLÚtflutningur
Name[it]=Esportazione a KML
Name[km]=KMLExport
Name[nb]=KMLeksport
Name[nl]=KMLExport
Name[pl]=EksportDoKML
Name[pt]=KMLExport
Name[pt_BR]=Exportar para KML
Name[ro]=KMLExport
Name[ru]=Экспорт в KML
Name[sk]=KMLExport
Name[sl]=KMLExport
Name[sv]=Export till KML
Name[tr]=KMLExport
Name[uk]=KMLExport
Name[x-test]=xxKMLExportxx
Name[zh_CN]=KML导出
Name[zh_TW]=KML 匯出
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_kmlexport
X-KIPI-ReqFeatures=ImagesHasTime
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam-4.14.0.tar.bz2: digikam-4.14.0/extra/kipi-plugins/kmlexport/kipiplugin_kmlexport.desktop.cmake <==
[Desktop Entry]
Comment=A tool to create KML files with geolocated images
Comment[bs]=Alat za kreiranje KML datoteka s geolociranim slikama
Comment[ca]=Una eina per crear fitxers KML per presentar imatges amb coordenades
Comment[cs]=Modul pro vytváření souborů KML s obrázky se souřadnicemi.
Comment[da]=Et værktøj til at oprette KML-filer med geolokaliserede billeder
Comment[de]=Ein Werkzeug zum Erstellen von KML-Dateien mit Bilder, die geografische Informationen enthalten.
Comment[el]=Ένα πρόσθετο δημιουργίας αρχείων KML με γεωχωρικές εικόνες
Comment[en_GB]=A tool to create KML files with geolocated images
Comment[es]=Una herramienta para crear archivos KML con imágenes geolocalizadas
Comment[fr]=Un outil de création de fichiers « KML » avec des images géolocalisées.
Comment[gl]=Unha ferramenta para crear ficheiros KML con imaxes que inclúen coordenadas.
Comment[is]=Verkfæri til að búa til KML-skrár fyrir hnattstaðsetningu mynda.
Comment[it]=Uno strumento per creare file KML con immagini geolocalizzate.
Comment[nl]=Een hulpmiddel om KML-bestanden aan te maken met afbeeldingen met geo-locaties.
Comment[pl]=Narzędzie do tworzenia plików KML z obrazów o ustalonym położeniu geograficznym
Comment[pt]=Um 'plugin' para criar ficheiros KML com imagens geo-localizadas.
Comment[pt_BR]=Ferramenta para criar arquivos KML com imagens geolocalizadas.
Comment[ru]=Инструмент для создания файлов KML из изображений с географическими координатами
Comment[sk]=Nástroj na tvorbu KML súborov s geolokalizovanými obrázkami
Comment[sl]=Orodje za ustvarjanje datotek KML, ki predstavijo sliko s koordinatami
Comment[sv]=Ett verktyg för att skapa KML-filer med geografiskt lokaliserade bilder
Comment[tr]=Konum içeren resimlerden KML dosyaları oluşturmak için bir araç
Comment[uk]=Інструмент для створення файлів KML для показу зображення з координатами
Comment[x-test]=xxA tool to create KML files with geolocated imagesxx
Icon=applications-development-web
UntranslatedGenericName=KMLExport
Name=KMLExport
Name[bg]=Изнасяне в KML
Name[bs]=KMLExport
Name[ca]=Exportador a KML
Name[ca@valencia]=Exportador a KML
Name[cs]=KMLExport
Name[da]=KMLExport
Name[de]=KMLExport
Name[el]=KMLExport
Name[en_GB]=KMLExport
Name[es]=KMLExport
Name[et]=KML-i eksport
Name[fi]=KML-vienti
Name[fr]=Export « KML »
Name[ga]=KMLExport
Name[gl]=KMLExport
Name[hu]=KML exportálás
Name[is]=KMLÚtflutningur
Name[it]=Esportazione a KML
Name[km]=KMLExport
Name[nb]=KMLeksport
Name[nl]=KMLExport
Name[pl]=EksportDoKML
Name[pt]=KMLExport
Name[pt_BR]=Exportar para KML
Name[ro]=KMLExport
Name[ru]=Экспорт в KML
Name[sk]=KMLExport
Name[sl]=KMLExport
Name[sv]=Export till KML
Name[tr]=KMLExport
Name[uk]=KMLExport
Name[x-test]=xxKMLExportxx
Name[zh_CN]=KML导出
Name[zh_TW]=KML 匯出
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_kmlexport
X-KIPI-ReqFeatures=ImagesHasTime
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
